
# Copyright (c) 2003,2004 Guilherme Salgado
# All rights reserved.
#
# This file is part of coverhunter.
# 
# coverhunter is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# coverhunter is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with coverhunter; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Author: Guilherme Salgado <salgado@async.com.br>
#

import ConfigParser, os

import Image

from amazon import Bag

class Album:
    def __init__(self, path, name, artist):
        if os.path.isfile(path):
            raise IOError
        self.path = path
        self.cover_filename = '.folder.png'
        # this is a list of amazon.Bag instances. each Bag's cover is
        # accessed by Bag.coverfile
        self.found_covers = []
        # sometimes we can receive None as name and artist, and this isn't
        # good when setting text on gtk.Entry. that's why we use the above
        # code instead of default parameters.
        self.name = name or ''
        self.artist = artist or ''
        self.cover = Bag()
        if self.has_cover():
            self.cover.ProductName = self.get_full_str()
            self.cover.coverfile = os.path.join(self.path, self.cover_filename)

    def clear_tmp_covers(self):
        map(lambda cover: os.unlink(cover.coverfile), self.found_covers)
        self.found_covers = []

    def get_cover(self):
        assert self.has_cover()
        return self.cover.coverfile

    def get_all_covers(self):
        if self.has_cover():
            return [self.cover] + self.found_covers
        return self.found_covers

    def has_cover(self):
        return os.path.isfile(os.path.join(self.path, self.cover_filename))

    def set_cover(self, bag):
        icon = Image.open(bag.coverfile)
        if self.has_cover():
            os.unlink(self.cover.coverfile)
        self.cover.ProductName = bag.ProductName
        self.cover.coverfile = os.path.join(self.path, self.cover_filename)
        icon.save(self.cover.coverfile, 'PNG')

        dir_file = os.path.join(self.path, '.directory')
        cf = MyParser()
        try:
            cf.read(dir_file)
        except:
            pass
        if not cf.has_section('Desktop Entry'):
            cf.add_section('Desktop Entry')
        cf.set('Desktop Entry', 'Type', 'Directory')
        cf.set('Desktop Entry', 'Icon', self.cover.coverfile)
        cf.write(open(dir_file, 'w'))

    def get_full_str(self):
        if self.artist and self.name:
            album_str = self.artist + ' - ' + self.name
        elif self.artist:
            album_str = self.artist
        else:
            album_str = self.name
        return album_str


class MyParser(ConfigParser.SafeConfigParser):
    def optionxform(self, option):
        # we override this method cause we don't want lowercase options.
        return option

    def write(self, fp):
        # this was overrided to make no use of white spaces around '='.
        """Write an .ini-format representation of the configuration state."""
        if self._defaults:
            fp.write("[%s]\n" % DEFAULTSECT)
            for (key, value) in self._defaults.items():
                fp.write("%s=%s\n" % (key, str(value).replace('\n', '\n\t')))
            fp.write("\n")
        for section in self._sections:
            fp.write("[%s]\n" % section)
            for (key, value) in self._sections[section].items():
                if key != "__name__":
                    fp.write("%s=%s\n" %
                             (key, str(value).replace('\n', '\n\t')))
            fp.write("\n")


def guess_album_info(path):
    """Given a path, try to extract the artist and album.
       Works in cases such as:

        artist/album
        artist - album/
        ...

    """
    try:
        p = os.path.split(path)
        artist = p[0]
        album = p[-1]
    except:
        artist = None
        album = path

    if album.find("- ") > 0:
        artist, album = album.split("-", 1)

    artist = artist.strip()
    album = album.strip()

    if not len(artist):
        artist = None
    if not len(album):
        album = None

    return artist, album

