
# Copyright (c) 2003,2004 Guilherme Salgado
# All rights reserved.
#
# This file is part of coverhunter.
# 
# coverhunter is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# coverhunter is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with coverhunter; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Author: Guilherme Salgado <salgado@async.com.br>
#

import os, sys

import pygtk ; pygtk.require('2.0')
import gobject, gtk
from gtk import gdk


class ListView(gtk.TreeView):
    """This is a base class to be used on AlbumList and CoverList"""
    
    def __init__(self, headers_visibility, *columns):
        self.model = gtk.ListStore(*columns)
        gtk.TreeView.__init__(self, self.model)
        self.set_headers_visible(headers_visibility)
        self.set_rules_hint(True)
        self.create_columns()

    def create_columns(self):
        """Create the columns of the TreeView"""
        pass

    def append(self, item):
        pass

    def clear(self):
        self.model.clear()

    def dump_column(self, col):
        data = []
        self.model.foreach(lambda m, p, i: data.append(m.get_value(i, col)))
        return data

    def select_iter(self, iter):
        self.get_selection().select_iter(iter)

    def select_path(self, path):
        self.get_selection().select_path(path)

    def iter_is_selected(self, iter):
        return self.get_selection().iter_is_selected(iter)

    def path_is_selected(self, path):
        return self.get_selection().path_is_selected(path)


class DirSelection(gtk.FileSelection):
    def __init__(self, parent_window, title=None):
        gtk.FileSelection.__init__(self, title)
        self.set_transient_for(parent_window)
        self.ok_button.connect('clicked', self.ok_clicked)
        self.cancel_button.connect('clicked', self.cancel_clicked)
        self.root = None
        self.hide_fileop_buttons()
        # HACK, HACK, HACK!!
        self.file_list.parent.hide()

    def ok_clicked(self, button):
        self.root = self.get_filename()
        self.hide()

    def cancel_clicked(self, button):
        self.hide()
        self.root = None


class SetTokenDialog(gtk.Dialog):
    def __init__(self, parent):
        gtk.Dialog.__init__(self, 'Set Amazon Token', parent, 
                            gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                            (gtk.STOCK_OK, gtk.RESPONSE_OK,
                             gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
        self.token = None
        token_area = gtk.HBox(spacing=4)
        token_area.pack_start(gtk.Label('Amazon Token:'), expand=False)
        self.token_entry = gtk.Entry()
        self.token_entry.connect('changed', self.on_token_changed)
        token_area.pack_start(self.token_entry, expand=True)
        info_area = gtk.VBox(spacing=4)
        msg = "Please enter your Amazon Web Services Token.\n"
        msg += "You can obtain this token free of charge here:\n"
        msg += "https://associates.amazon.com/exec/panama/associates/join/developer/application.html"
        msg = gtk.Label(msg)
        msg.set_selectable(True)
        info_area.pack_start(msg)
        info_area.pack_start(token_area)
        info_area.set_property('border-width', 5)
        info_area.show_all()
        self.vbox.pack_start(info_area)

    def on_token_changed(self, widget):
        self.token = widget.get_text()


def about_dialog(parent, version):
    m = "Cover Hunter %s by Guilherme Salgado <salgado@async.com.br>.\n" % \
        version
    m += "http://sourceforge.net/projects/coverhunter/\n\n"
    m += "Python wrapper for the Amazon web API by Mark Pilgrim "
    m += "<mark@diveintomark.org>"
    
    dialog = gtk.Dialog("About Cover Hunter", parent,
                        gtk.DIALOG_DESTROY_WITH_PARENT,
                        (gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
    label = gtk.Label(m)
    label.set_padding(5, 5)
    label.set_selectable(True)
    label.show()
    dialog.vbox.pack_start(label)
    dialog.run()
    dialog.destroy()

def msg_dialog(parent, message, message_type):
    dialog = gtk.MessageDialog(parent, gtk.DIALOG_DESTROY_WITH_PARENT,
                               message_type, gtk.BUTTONS_CLOSE, message)
    dialog.run()
    dialog.destroy()


def warning_dialog(message, parent=None):
    msg_dialog(parent, message, gtk.MESSAGE_WARNING)

