
# Copyright (c) 2003,2004 Guilherme Salgado
# All rights reserved.
#
# This file is part of coverhunter.
# 
# coverhunter is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# coverhunter is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with coverhunter; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Author: Guilherme Salgado <salgado@async.com.br>
#

import os
import id3
from ogg import vorbis

TYPE_OGG = 0
TYPE_MP3 = 1

types = [TYPE_OGG, TYPE_MP3]


class MusicFile:
    def __init__(self, file, type=None):
        if not os.path.isfile(file):
            raise IOError
        self.file = file
        if type is None:
            # try to get file type from extension (mp3|ogg)
            type = self.get_type_from_name()
        self.type = type
        self.artist, self.album = get_info(file, self.type)

    def get_type_from_name(self):
        type = None
        extension = self.file[-3:].upper()
        if extension == "OGG":
            type = TYPE_OGG
        elif extension == "MP3":
            type = TYPE_MP3
        return type
        

def get_info(file, type):
    if type not in types:
        raise TypeError

    if type == TYPE_MP3:
        return get_info_from_mp3(file)
    elif type == TYPE_OGG:
        return get_info_from_ogg(file)

def get_info_from_mp3(file):
    id3v2_album = id3v2_artist = None
    id3v1 = id3.ID3v1(file)
    id3v2 = id3.ID3v2(file)

    for frame in id3v2.frames:
        if frame.id == 'TPE1':
            id3v2_artist = frame.value
        elif frame.id == 'TALB':
            id3v2_album = frame.value

    artist = id3v1.artist or id3v2_artist
    album = id3v1.album or id3v2_album
    return artist, album

def get_info_from_ogg(file):
    f = vorbis.VorbisFile(file)
    meta = f.comment().as_dict()
    
    artist = meta.get('ARTIST')
    if artist is not None:
        artist = artist[0]
    
    album = meta.get('ALBUM')
    if album is not None:
        album = album[0]
    return artist, album

